@@ -107,7 +107,7 @@ Generated from I</proc/meminfo>.
    SwapUsedPer     -  Total size of swap space is used in percent.
    SwapTotal       -  Total size of swap space in kilobytes.
 
-=head2 PgSwStats, PgSwStats
+=head2 PgSwStats, C<PgSwStats()>
 
 Generated from F</proc/stat> or F</proc/vmstat>.
 
@@ -129,7 +129,7 @@ Generated from F</proc/net/dev>.
    RxCompr         -  Number of compressed packets received.
    RxMulti         -  Number of multicast packets received.
    TxBytes         -  Number of bytes transmitted.
-   TxPacktes       -  Number of packets transmitted.
+   TxPackets       -  Number of packets transmitted.
    TxErrs          -  Number of errors that happend while transmitting packets.
    TxDrop          -  Number of packets that were dropped.
    TxFifo          -  Number of FIFO overruns that happend on transmitted packets.
@@ -260,9 +260,9 @@ Generated with C<localtime(time)>.
 
 =head1 EXAMPLES
 
-You can find very a simple script for tests under F<Linux-Statistics-1.13/Examples/>.
+You can find very a simple script for tests under F<Linux-Statistics-1.14/Examples/>.
 The script calls F<SimpleCheck> and shows you the collected data with C<Data::Dumper>.
-The following examples lie under F<Linux-Statistics-1.13/Examples/> as well.
+The following example scripts lie under F<Linux-Statistics-1.14/Examples/> as well.
 
 A very simple perl script could looks like this:
 
@@ -295,7 +295,7 @@ Example to collect network statistics with a nice output:
 
          my @list = qw( RxBytes  RxPackets  RxErrs   RxDrop
                         RxFifo   RxFrame    RxCompr  RxMulti
-                        TxBytes  TxPacktes  TxErrs   TxDrop
+                        TxBytes  TxPackets  TxErrs   TxDrop
                         TxFifo   TxColls    TxCarr   TxCompr );
 
          print ' ' x 6;
@@ -344,7 +344,7 @@ You can collect the statistics in a loop as well:
          my $obj = Linux::Statistics->new( ProcStats => 1, TimeStamp => 1 );
 
          print "Report/Statistic for ProcStats\n";
-         printf '%8s', $_ for qw(Time User Nice System Idle IOWait Total New);
+         printf '%8s', $_ for qw(Time User System Total Nice IOWait Idle New);
          print "\n";
 
          while (1) {
@@ -352,7 +352,7 @@ You can collect the statistics in a loop as well:
             my $stats = $obj->getStats;
 
             print "$stats->{TimeStamp}->{Time}";
-            printf '%8s', $stats->{ProcStats}->{$_} for keys %{$stats->{ProcStats}};
+            printf '%8s', $stats->{ProcStats}->{$_} for qw(User System Total Nice IOWait Idle New);
             print "\n";
          }
 
@@ -435,6 +435,10 @@ Please report all bugs to <jschulz@bloonix.de>.
 If there are statistics you need but not generated by this module please send me an email
 with your wishs or a function ready to built in :-).
 
+Maybe this module do not runs on your architecture fine because there are a lot of differences
+between the /proc filesystems of your arch and a simple x86 system. In this case it would be
+fine if you contact me and we looks for a solution.
+
 =head1 AUTHOR
 
 Jonny Schulz <jschulz@bloonix.de>.
@@ -452,7 +456,7 @@ package Linux::Statistics;
 
 use strict;
 use warnings;
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 # Disk statictics are since 2.4 kernel found in /proc/partitions, but since
 # kernel 2.6 this statistics are now in /proc/diskstats. Further the paging
@@ -540,9 +544,9 @@ sub getStats {
    }
 
    if ($options->{Processes}) {
-      open FU,'<',$file{uptime} or die "Statistics: can't open $file{uptime}";
-      my $uptime = (split /\s+/, <FU>)[0];
-      close FU;
+      open my $fu, '<', $file{uptime} or die "Statistics: can't open $file{uptime}";
+      my $uptime = (split /\s+/, <$fu>)[0];
+      close $fu;
       $istat->{uptime} = $uptime - $istat->{uptime};
       $rstat->{Processes} = Processes();
       my $r_stat = $rstat->{Processes};
@@ -621,36 +625,36 @@ sub SysInfo {
    my %sys;
 
    for (qw(Hostname Domain Kernel Release Version)) {
-      open FH,'<',$file{$_} or die "Statistics: can't open $file{$_}";
-      $sys{$_} = <FH>;
-      close FH;
+      open my $fht, '<', $file{$_} or die "Statistics: can't open $file{$_}";
+      $sys{$_} = <$fht>;
+      close $fht;
    }
 
-   open FM,'<',$file{meminfo} or die "Statistics: can't open $file{meminfo}";
-   while (<FM>) {
-      if (/^MemTotal:\s+(\d+ \w+)/) {
+   open my $fhm, '<', $file{meminfo} or die "Statistics: can't open $file{meminfo}";
+   while (defined (my $line = <$fhm>)) {
+      if ($line =~ /^MemTotal:\s+(\d+ \w+)/) {
          $sys{MemTotal} = $1;
-      } elsif (/^SwapTotal:\s+(\d+ \w+)/) {
+      } elsif ($line =~ /^SwapTotal:\s+(\d+ \w+)/) {
          $sys{SwapTotal} = $1;
       }
    }
-   close FM;
+   close $fhm;
 
    $sys{CountCPUs} = 0;
-   open FC,'<',$file{cpuinfo} or die  die "Statistics: can't open $file{cpuinfo}";
-   while (<FC>) {
-      if (/^processor\s*:\s*\d+/) {            # x86
+   open my $fhc, '<', $file{cpuinfo} or die  die "Statistics: can't open $file{cpuinfo}";
+   while (defined (my $line = <$fhc>)) {
+      if ($line =~ /^processor\s*:\s*\d+/) {            # x86
          $sys{CountCPUs}++;
-      } elsif (/^# processors\s*:\s*(\d+)/) {  # s390
+      } elsif ($line =~ /^# processors\s*:\s*(\d+)/) {  # s390
          $sys{CountCPUs} = $1;
          last;
       }
    }
-   close FC;
+   close $fhc;
 
-   open FU,'<',$file{uptime} or die "Statistics: can't open $file{uptime}";
+   open my $fhu, '<', $file{uptime} or die "Statistics: can't open $file{uptime}";
 
-   foreach (split /\s+/, <FU>) {
+   foreach (split /\s+/, <$fhu>) {
       my $s = sprintf('%li',$_);
       my $d = 0;
       my $h = 0;
@@ -668,7 +672,7 @@ sub SysInfo {
       $sys{IdleTime} = "${d}d ${h}h ${m}m ${s}s";
    }
 
-   close FU;
+   close $fhu;
 
    foreach my $key (keys %sys) {
       chomp $sys{$key};
@@ -682,21 +686,21 @@ sub SysInfo {
 sub ProcStats {
    my %stat;
 
-   open STAT,'<',$file{stats} or die "Statistics: can't open $file{stats}";
+   open my $fhp, '<', $file{stats} or die "Statistics: can't open $file{stats}";
 
-   while (<STAT>) {
-      if (/^cpu\s+(.*)$/) {
+   while (defined (my $line = <$fhp>)) {
+      if ($line =~ /^cpu\s+(.*)$/) {
          @stat{qw(User Nice System Idle IOWait)} = split /\s+/, $1;
          # IOWait is only set as fifth parameter
          # by kernel versions higher than 2.4
          $stat{IOWait} = 0 unless defined $stat{IOWait};
          $stat{Uptime} = $stat{User} + $stat{Nice} + $stat{System} + $stat{Idle} + $stat{IOWait};
-      } elsif (/^processes (.*)/) {
+      } elsif ($line =~ /^processes (.*)/) {
          $stat{New} = $1;
       }
    }
 
-   close STAT;
+   close $fhp;
 
    return \%stat;
 }
@@ -704,9 +708,11 @@ sub ProcStats {
 sub MemStats {
    my %mem;
 
-   open MEM,'<',$file{meminfo} or die "Statistics: can't open $file{meminfo}";
-   while (<MEM>) { $mem{$1} = $2 if /^(MemTotal|MemFree|Buffers|Cached|SwapTotal|SwapFree):\s*(\d+)/ }
-   close MEM;
+   open my $fhm, '<', $file{meminfo} or die "Statistics: can't open $file{meminfo}";
+   while (defined (my $line = <$fhm>)) {
+      $mem{$1} = $2 if $line =~ /^(MemTotal|MemFree|Buffers|Cached|SwapTotal|SwapFree):\s*(\d+)/;
+   }
+   close $fhm;
 
    $mem{MemUsed}     = sprintf('%u',$mem{MemTotal} - $mem{MemFree});
    $mem{MemUsedPer}  = sprintf('%.2f',100 * $mem{MemUsed} / $mem{MemTotal});
@@ -719,37 +725,37 @@ sub MemStats {
 sub PgSwStats {
    my %stat;
 
-   open STAT,'<',$file{stats} or die "Statistics: can't open $file{stats}\n";
+   open my $fhs, '<', $file{stats} or die "Statistics: can't open $file{stats}\n";
 
-   while (<STAT>) {
-      if (/^page (\d+) (\d+)$/) {
+   while (defined (my $line = <$fhs>)) {
+      if ($line =~ /^page (\d+) (\d+)$/) {
          @stat{qw(PageIn PageOut)} = ($1, $2);
-      } elsif (/^swap (\d+) (\d+)$/) {
+      } elsif ($line =~ /^swap (\d+) (\d+)$/) {
          @stat{qw(SwapIn SwapOut)} = ($1, $2);
       }
    }
 
-   close STAT;
+   close $fhs;
 
    # if paging and swapping are not found in /proc/stat
    # then let's try a look into /proc/vmstat (since 2.6)
 
    unless (defined $stat{SwapOut}) {
-      open VMSTAT,'<',$file{vmstat} or die "Statistics: can't open $file{vmstat}";
+      open my $fhv, '<', $file{vmstat} or die "Statistics: can't open $file{vmstat}";
 
-      while (<VMSTAT>) {
-         if (/^pgpgin (\d+)$/) {
+      while (defined (my $line = <$fhv>)) {
+         if ($line =~ /^pgpgin (\d+)$/) {
             $stat{PageIn} = $1;
-         } elsif (/^pgpgout (\d+)$/) {
+         } elsif ($line =~ /^pgpgout (\d+)$/) {
             $stat{PageOut} = $1;
-         } elsif (/^pswpin (\d+)$/) {
+         } elsif ($line =~ /^pswpin (\d+)$/) {
             $stat{SwapIn} = $1;
-         } elsif (/^pswpout (\d+)$/) {
+         } elsif ($line =~ /^pswpout (\d+)$/) {
             $stat{SwapOut} = $1;
          }
       }
 
-      close VMSTAT;
+      close $fhv;
    }
 
    return \%stat;
@@ -758,13 +764,13 @@ sub PgSwStats {
 sub NetStats {
    my (%net,%sum);
 
-   open NET,'<',$file{netstats} or die "Statistics: can't open $file{netstats}";
+   open my $fhn, '<', $file{netstats} or die "Statistics: can't open $file{netstats}";
 
-   while (<NET>) {
-      if (/^\s*(\w+):\s*(.*)/) {
+   while (defined (my $line = <$fhn>)) {
+      if ($line =~ /^\s*(\w+):\s*(.*)/) {
          @{$net{$1}}{qw(
             RxBytes  RxPackets  RxErrs   RxDrop     RxFifo  RxFrame
-            RxCompr  RxMulti    TxBytes  TxPacktes  TxErrs  TxDrop
+            RxCompr  RxMulti    TxBytes  TxPackets  TxErrs  TxDrop
             TxFifo   TxColls    TxCarr   TxCompr
          )} = split /\s+/, $2;
 
@@ -773,32 +779,30 @@ sub NetStats {
       }
    }
 
-   close NET;
-
+   close $fhn;
    return (\%net,\%sum);
 }
 
 sub SockStats {
    my %sock;
 
-   open SOCK,'<',$file{sockstats} or die "Statistics: can't open $file{sockstats}";
+   open my $fhs, '<', $file{sockstats} or die "Statistics: can't open $file{sockstats}";
 
-   while (<SOCK>) {
-      if (/sockets: used (\d+)/) {
+   while (defined (my $line = <$fhs>)) {
+      if ($line =~ /sockets: used (\d+)/) {
          $sock{Used} = $1;
-      } elsif (/TCP: inuse (\d+)/) {
+      } elsif ($line =~ /TCP: inuse (\d+)/) {
          $sock{Tcp} = $1;
-      } elsif (/UDP: inuse (\d+)/) {
+      } elsif ($line =~ /UDP: inuse (\d+)/) {
          $sock{Udp} = $1;
-      } elsif (/RAW: inuse (\d+)/) {
+      } elsif ($line =~ /RAW: inuse (\d+)/) {
          $sock{Raw} = $1;
-      } elsif (/FRAG: inuse (\d+)/) {
+      } elsif ($line =~ /FRAG: inuse (\d+)/) {
          $sock{IpFrag} = $1;
       }
    }
 
-   close SOCK;
-
+   close $fhs;
    return \%sock;
 }
 
@@ -809,9 +813,9 @@ sub DiskStats {
    # if diskstats (2.6) are not found then let's try to read
    # the partitions (2.4)
 
-   if (open DISK,'<',$file{diskstats}) {
-      while (<DISK>) {
-         if (/^\s+(\d+)\s+(\d+)\s+(\w+)\s+(\d+)\s+\d+\s+(\d+)\s+\d+\s+(\d+)\s+(\d+)\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+$/ && $4 && $6) {
+   if (open my $fhd, '<', $file{diskstats}) {
+      while (defined (my $line = <$fhd>)) {
+         if ($line =~ /^\s+(\d+)\s+(\d+)\s+(\w+)\s+(\d+)\s+\d+\s+(\d+)\s+\d+\s+(\d+)\s+(\d+)\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+$/ && $4 && $6) {
             for my $x ($disk{$3}) {
                $x->{Major}          = $1;
                $x->{Minor}          = $2;
@@ -822,7 +826,7 @@ sub DiskStats {
                $x->{TotalRequests} += $x->{ReadRequests} + $x->{WriteRequests};
                $x->{TotalBytes}    += $x->{ReadBytes} + $x->{WriteBytes};
             }
-         } elsif (/^\s+(\d+)\s+(\d+)\s+(\w+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)$/) {
+         } elsif ($line =~ /^\s+(\d+)\s+(\d+)\s+(\w+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)$/) {
             for my $x ($disk{$3}) {
                $x->{Major}          = $1;
                $x->{Minor}          = $2;
@@ -846,12 +850,11 @@ sub DiskStats {
             $sum{Bytes}         += $x->{TotalBytes};
          }
       }
-      close DISK;
-   }
-   elsif (open DISK,'<',$file{partitions}) {
-      while (<DISK>) {
+      close $fhd;
+   } elsif (open my $fhp, '<', $file{partitions}) {
+      while (defined (my $line = <$fhp>)) {
          tr/A-Z/a-z/;
-         next unless /^\s+(\d+)\s+(\d+)\s+\d+\s+(\w+)\s+(\d+)\s+\d+\s+(\d+)\s+\d+\s+(\d+)\s+(\d+)\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+$/ && $4 && $6;
+         next unless $line =~ /^\s+(\d+)\s+(\d+)\s+\d+\s+(\w+)\s+(\d+)\s+\d+\s+(\d+)\s+\d+\s+(\d+)\s+(\d+)\s+\d+\s+\d+\s+\d+\s+\d+\s+\d+$/ && $4 && $6;
          for my $x ($disk{$3}) {
             $x->{Major}          = $1;
             $x->{Minor}          = $2;
@@ -869,7 +872,7 @@ sub DiskStats {
             $sum{Bytes}         += $x->{TotalBytes};
          }
       }
-      close DISK;
+      close $fhp;
    } else {
       die "Statistics: can't open $file{diskstats} or $file{partitions}";
    }
@@ -880,18 +883,21 @@ sub DiskStats {
 sub DiskUsage {
    my (%disk_usage,$disk_name);
 
-   open DFK,"/bin/df -k |"  or die "Statistics: can't execute /bin/df -k";
+   open my $fhp, "/bin/df -k |" or die "Statistics: can't execute /bin/df -k";
 
-   while (<DFK>) {
-      s/%//g;
+   # filter the header
+   {my $null = <$fhp>;}
 
-      if (/^(.+?)\s+(.+)$/ && !$disk_name) {
+   while (defined (my $line = <$fhp>)) {
+      $line =~ s/%//g;
+
+      if ($line =~ /^(.+?)\s+(.+)$/ && !$disk_name) {
          @{$disk_usage{$1}}{qw(Total Usage Free UsagePer MountPoint)} = (split /\s+/, $2)[0..4];
-      } elsif (/^(.+?)\s*$/ && !$disk_name) {
+      } elsif ($line =~ /^(.+?)\s*$/ && !$disk_name) {
          # it can be that the disk name is to long and the rest
          # of the disk informations are in the next line ...
          $disk_name = $1;
-      } elsif (/^\s+(.*)$/ && $disk_name) {
+      } elsif ($line =~ /^\s+(.*)$/ && $disk_name) {
          # this line should contain the rest informations for the
          # disk name that we stored in the last loop
          @{$disk_usage{$disk_name}}{qw(Total Usage Free UsagePer MountPoint)} = (split /\s+/, $1)[0..4];
@@ -904,23 +910,22 @@ sub DiskUsage {
       }
    }
 
-   close DFK;
-
+   close $fhp;
    return \%disk_usage;
 }
 
 sub LoadAVG {
    my (%lavg,$proc);
 
-   open LAVG,'<',$file{loadavg} or die "Statistics: can't open $file{loadavg}";
+   open my $fha, '<', $file{loadavg} or die "Statistics: can't open $file{loadavg}";
 
    ( $lavg{AVG_1}
    , $lavg{AVG_5}
    , $lavg{AVG_15}
    , $proc
-   ) = (split /\s+/, <LAVG>)[0..3];
+   ) = (split /\s+/, <$fha>)[0..3];
 
-   close LAVG;
+   close $fha;
 
    ( $lavg{RunQueue}
    , $lavg{Count}
@@ -932,18 +937,18 @@ sub LoadAVG {
 sub FileStats {
    my %fstat;
 
-   open FNR,'<',$file{file_nr} or die "Statistics can't open $file{file_nr}";
-   @fstat{qw(fhAlloc fhFree fhMax)} = (split /\s+/, <FNR>)[0..2];
-   close FNR;
+   open my $fhf, '<', $file{file_nr} or die "Statistics can't open $file{file_nr}";
+   @fstat{qw(fhAlloc fhFree fhMax)} = (split /\s+/, <$fhf>)[0..2];
+   close $fhf;
 
-   open INR,'<',$file{inode_nr} or die "Statistics can't open $file{inode_nr}";
-   @fstat{qw(inAlloc inFree)} = (split /\s+/, <INR>)[0..1];
+   open my $fhi, '<', $file{inode_nr} or die "Statistics can't open $file{inode_nr}";
+   @fstat{qw(inAlloc inFree)} = (split /\s+/, <$fhi>)[0..1];
    $fstat{inMax} = $fstat{inAlloc} + $fstat{inFree};
-   close INR;
+   close $fhi;
 
-   open DENT,'<',$file{dentries} or die "Statistics can't open $file{dentries}";
-   @fstat{qw(Dentries Unused AgeLimit WantPages)} = (split /\s+/, <DENT>)[0..3];
-   close DENT;
+   open my $fhd, '<', $file{dentries} or die "Statistics can't open $file{dentries}";
+   @fstat{qw(Dentries Unused AgeLimit WantPages)} = (split /\s+/, <$fhd>)[0..3];
+   close $fhd;
 
    return \%fstat;
 }
@@ -951,14 +956,14 @@ sub FileStats {
 sub initProcesses {
    my %sps;
 
-   opendir PDIR,$file{procdir}  or die "Statistics: can't open directory $file{procdir}";
-   my @prc = grep /^\d+$/, readdir PDIR; 
-   closedir PDIR;
+   opendir my $pdir, $file{procdir}  or die "Statistics: can't open directory $file{procdir}";
+   my @prc = grep /^\d+$/, readdir $pdir; 
+   closedir $pdir;
 
    foreach my $pid (@prc) {
-      if (open PRC,'<',"$file{procdir}/$pid/stat") {
-         @{$sps{$pid}}{qw(MinFLT CMinFLT MayFLT CMayFLT UTime STime CUTime CSTime StartTime)} = (split /\s+/, <PRC>)[9..16,21];
-         close PRC; 
+      if (open my $fhp, '<', "$file{procdir}/$pid/stat") {
+         @{$sps{$pid}}{qw(MinFLT CMinFLT MayFLT CMayFLT UTime STime CUTime CSTime StartTime)} = (split /\s+/, <$fhp>)[9..16,21];
+         close $fhp; 
       } else {
          delete $sps{$pid};
          next;
@@ -971,49 +976,49 @@ sub initProcesses {
 sub Processes {
    my (%sps,%userids);
 
-   opendir PDIR,$file{procdir}  or die "Statistics: can't open directory $file{procdir}";
+   opendir my $pdir, $file{procdir} or die "Statistics: can't open directory $file{procdir}";
 
    # we get all the PIDs from the /proc filesystem. if we can't open a file
    # of a process, then it can be that the process doesn't exist any more and
    # we will delete the hash key.
-   my @prc = grep /^\d+$/, readdir PDIR;
+   my @prc = grep /^\d+$/, readdir $pdir;
 
-   closedir PDIR;
+   closedir $pdir;
 
    # we trying to get the UIDs for each linux user
-   open PWD,'<',$file{passwd} or die die "Statistics: can't open $file{passwd}";
+   open my $fhp, '<', $file{passwd} or die die "Statistics: can't open $file{passwd}";
 
-   while (<PWD>) {
-      next if /^(#|$)/;
-      my ($user,$uid) = (split /:/,$_)[0,2];
+   while (defined (my $line = <$fhp>)) {
+      next if $line =~ /^(#|$)/;
+      my ($user,$uid) = (split /:/,$line)[0,2];
       $userids{$uid} = $user;
    }
 
-   close PWD;
+   close $fhp;
 
-   open FU,'<',$file{uptime} or die "Statistics: can't open $file{uptime}";
-   my $uptime = (split /\s+/, <FU>)[0];
-   close FU;
+   open my $fhu, '<', $file{uptime} or die "Statistics: can't open $file{uptime}";
+   my $uptime = (split /\s+/, <$fhu>)[0];
+   close $fhu;
 
    foreach my $pid (@prc) {
 
       #  memory usage for each process
-      if (open MEM,'<',"$file{procdir}/$pid/statm") {
-         @{$sps{$pid}}{qw(Size Resident Share TRS DRS LRS DT)} = split /\s+/, <MEM>;
-         close MEM;
+      if (open my $fhm, '<', "$file{procdir}/$pid/statm") {
+         @{$sps{$pid}}{qw(Size Resident Share TRS DRS LRS DT)} = split /\s+/, <$fhm>;
+         close $fhm;
       } else {
          delete $sps{$pid};
          next;
       }
 
       #  different other informations for each process
-      if (open PRC,'<',"$file{procdir}/$pid/stat") {
+      if (open my $fhp, '<', "$file{procdir}/$pid/stat") {
          @{$sps{$pid}}{qw(
             Pid Comm State PPid PGrp Session TTYnr MinFLT
             CMinFLT MayFLT CMayFLT UTime STime CUTime CSTime
             Prior Nice StartTime VSize NSwap CNSwap CPU
-         )} = (split /\s+/, <PRC>)[0..6,9..18,21..22,35..36,38];
-         close PRC;
+         )} = (split /\s+/, <$fhp>)[0..6,9..18,21..22,35..36,38];
+         close $fhp;
       } else {
          delete $sps{$pid};
          next;
@@ -1032,28 +1037,27 @@ sub Processes {
       $sps{$pid}{ActiveTime} = sprintf '%02d:%02d:%02d', $d, $h, $m;
 
       # determine the owner of the process
-      if (open UID,'<',"$file{procdir}/$pid/status") {
-         while (<UID>) {
-            s/\t/ /;
-            next unless /^Uid:\s+(\d+)/;
+      if (open my $fhu, '<', "$file{procdir}/$pid/status") {
+         while (defined (my $line = <$fhu>)) {
+            $line =~ s/\t/ /;
+            next unless $line =~ /^Uid:\s+(\d+)/;
             $sps{$pid}{Owner} = $userids{$1} if $userids{$1};
          }
 
          $sps{$pid}{Owner} = 'n/a' unless $sps{$pid}{Owner};
-
-         close UID;
+         close $fhu;
       } else {
          delete $sps{$pid};
          next;
       }
 
       #  command line for each process
-      if (open CMD,'<',"$file{procdir}/$pid/cmdline") {
-         $sps{$pid}{CMDLINE} =  <CMD>;
+      if (open my $fhc, '<', "$file{procdir}/$pid/cmdline") {
+         $sps{$pid}{CMDLINE} =  <$fhc>;
          $sps{$pid}{CMDLINE} =~ s/\0/ /g if $sps{$pid}{CMDLINE};
          $sps{$pid}{CMDLINE} =  'n/a' unless $sps{$pid}{CMDLINE};
          chomp $sps{$pid}{CMDLINE};
-         close CMD;
+         close $fhc;
       }
    }
 
